# Vectors

LibRapid provides a highly optimised fixed-size vector library which supports all primitive types as well as
user-defined ones (assuming they implement the required operations).

```{toctree}
:hidden:
Vector Listing <vectorListing>
```
